# SpiffyPlots

[![Build Status](https://travis-ci.com/JRBCH/spiffyplots.svg?token=i92PyxWJ7xxe45sHGGQE&branch=master)](https://travis-ci.com/JRBCH/spiffyplots)
[![PyPI version](https://badge.fury.io/py/spiffyplots.svg)](https://badge.fury.io/py/spiffyplots)
[![GitHub last commit](https://img.shields.io/github/last-commit/google/skia.svg?style=flat)]()

A collection of matplotlib style sheets and plotting tools for publication-ready figures


* Free software: MIT license
* Documentation: https://spiffyplots.readthedocs.io.


## Features

* TODO

## Credits

 * This package was created with Cookiecutter and the `audreyr/cookiecutter-pypackage` project template.

 * The idea for easy-to-use and pypi-deployable matplotlib stylesheets stems from John Garrett's
 [SciencePlots](https://github.com/garrettj403/SciencePlots) package.
